# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .doc_response import DocResponse

__all__ = ["WorkspaceGetDocumentsResponse"]

WorkspaceGetDocumentsResponse: TypeAlias = List[DocResponse]
